"""Terminal Tutor - Learn commands as you type them."""

__version__ = "0.1.12"
__author__ = "Terminal Tutor Team"
__description__ = "Interactive command descriptions for your terminal"

from .core import CommandTutor

__all__ = ["CommandTutor"]
